<?php

/**
 * This is the model class for table "{{comment}}".
 *
 * The followings are the available columns in table '{{comment}}':
 * @property integer $id
 * @property string $content
 * @property integer $userid
 * @property integer $created
 * @property integer $updated
 * @property integer $topicid
 */
class Comment extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Comment the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{comment}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('content', 'required'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, content, userid, created, updated, topicid', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'author' => array(self::BELONGS_TO, 'User', 'userid', 'condition'=>'', 'order'=>''),
			'topic' => array(self::BELONGS_TO, 'Topic', 'topicid', 'condition'=>'', 'order'=>''),


		);
	}
/*	public function getAuthor(){
		return User::model()->findByPk($this->userid);
	}*/
	public function getAuthorLink()
	{
		return CHtml::link($this->author->username,SForumModule::userUrl($this->author->id),array());
	}
	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'content' => 'Content',
			'userid' => 'Userid',
			'created' => 'Created',
			'updated' => 'Updated',
			'topicid' => 'Topicid',
		);
	}

	public function beforeSave()
	{
		if(parent::beforeSave())
		{
			if($this->isNewRecord)
			{
				$this->created=$this->updated=time();
				$this->userid=Yii::app()->user->id;			
			}
			else
				$this->updated=time();
			return true;
		}
		else
			return false;

	}
	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('content',$this->content,true);
		$criteria->compare('userid',$this->userid);
		$criteria->compare('created',$this->created);
		$criteria->compare('updated',$this->updated);
		$criteria->compare('topicid',$this->topicid);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}