<?php

/**
 * This is the model class for table "{{topic}}".
 *
 * The followings are the available columns in table '{{topic}}':
 * @property integer $id
 * @property string $title
 * @property string $content
 * @property integer $status
 * @property integer $created
 * @property integer $updated
 * @property integer $userid
 */
class Topic extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Topic the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{topic}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{

		return array(
			array('title, content,category', 'required'),
			array('title', 'length', 'max'=>128),

			array('id, title, content, category,status, created, updated, userid,sticky', 'safe', 'on'=>'search'),
		);
	}


	public function relations()
	{

		return array(
			'comments' => array(self::HAS_MANY, 'Comment', 'topicid', 'condition'=>''),// 'order'=>'comments.created DESC'),
			'commentCount' => array(self::STAT, 'Comment', 'topicid'),
			'latestComment' => array(self::HAS_MANY, 'Comment', 'topicid', 'limit'=>1),
			'categoryModel'=>array(self::BELONGS_TO,'Category','category'),


		);
	}

	public function defaultScope()
	{
		return array(
		);
	}

	public function scopes()
	{
		return array(
			'sticky'=>array('condition'=>'sticky=1'),
			'trashbin'=>array('condition'=>'status=0'),
			);
	}

	public function getUrl()
	{
		return Yii::app()->createUrl('/sforum/topic/view', array(
			'id'=>$this->id,
			'title'=>$this->title,
		));
	}

	public function getIsSticky()
	{
		if($this->sticky==1)
			return true;
		else
			return false;
	}
	public function getAuthor(){
		$userClass = Yii::app()->controller->module->userClass;
		return $userClass::model()->findByPk($this->userid);
	}

	public function getAuthorLink()
	{
		if(!isset($this->author))
		return;
		return CHtml::link($this->author->username,SForumModule::userUrl($this->author->id),array());
	}
	public function getFiles( $order=1){
		$dir = Yii::app()->getBasePath()."/../uploads/".$this->id;
		if ( !is_dir( $dir ) )
				mkdir($dir,0777,true); 
		$files = array_diff(scandir($dir,$order), array('..', '.'));
		$links = array();

		return $files;
	
	}
	public function beforeSave(){
		if(parent::beforeSave())
		{
			if($this->isNewRecord)
			{
				$this->created=$this->updated=time();
				$this->userid=Yii::app()->user->id;
				$status=Yii::app()->controller->module->newTopicStatus;
				if($status =="visible")
					$this->status = 1;
				elseif($status == 'hidden')
					$this->status = 0;
			}
			else
				$this->updated=time();
			return true;
		}
		else
			return false;

	}
	public function afterDelete()
	{
		Comment::model()->findAll(array('topicid'=>$this->id))->delete();
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'title' => 'Title',
			'content' => 'Content',
			'status' => 'Status',
			'created' => 'Created',
			'updated' => 'Updated',
			'userid' => 'Userid',
			'category'=>'Category',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('title',$this->title,true);
		$criteria->compare('content',$this->content,true);
		$criteria->compare('status',$this->status);
		$criteria->compare('created',$this->created);
		$criteria->compare('updated',$this->updated);
		$criteria->compare('userid',$this->userid);
		$criteria->compare('category',$this->category);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}